==> vue-connect-ui-0.0.0.tgz: package/src/components/button/button.rules.js <==
import { StyleSheet } from 'fela-tools'
import { BUTTON, COLOR, TRANSITION } from '../../core/constants'
import { offset } from '../../core/utils'
import transition from '../../rules/transition/transition'
import button from '../../rules/button/button'
import layout from '../../rules/layout/layout'
import edges from '../../rules/edges/edges'
import flex from '../../rules/flex/flex'

export default StyleSheet.create({
  button: ({ color, disabled, outline, outerSize, isSolid }) => ({
    pointerEvents: disabled ? 'none' : null,
    opacity: disabled ? 0.5 : null,
    borderRadius: outerSize * 0.5,
    minWidth: outerSize,
    height: outerSize,
    extend: [
      button({
        fill: isSolid ? color : COLOR.TRANSPARENT,
        outline: outline ? null : 'none',
        border: {
          width: BUTTON.BORDER_WIDTH,
          color
        }
      }),
      layout({
        align: 'center'
      }),
      flex({
        shrink: 0
      }),
      transition({
        property: 'opacity',
        duration: TRANSITION.UI.duration,
        easing: TRANSITION.UI.easing
      })
    ],
    onHover: {
      opacity: 0.75
    },
    onActive: {
      opacity: 0.90
    }
  }),
  icon: ({ text, iconSize, innerSize }) => {
    const padding = offset(innerSize, iconSize)
    const paddingLeft = text ? padding + 8 : padding
    return edges({
      prefix: 'padding',
      edges: {
        top: padding,
        right: padding,
        bottom: padding,
        left: paddingLeft
      }
    })
  },
  text: ({ icon, innerSize }) => {
    const padding = innerSize * 0.5
    const paddingLeft = icon ? 2 : padding
    return edges({
      prefix: 'padding',
      edges: {
        right: padding,
        left: paddingLeft
      }
    })
  }
})

==> vue-connect-ui-0.7.0.tgz: package/src/components/button/button.rules.js <==
import { StyleSheet } from 'fela-tools'
import { BUTTON, COLOR, TRANSITION } from '../../core/constants'
import { offset } from '../../core/utils'
import transition from '../../rules/transition/transition'
import button from '../../rules/button/button'
import layout from '../../rules/layout/layout'
import edges from '../../rules/edges/edges'
import flex from '../../rules/flex/flex'

export default StyleSheet.create({
  button: ({ color, disabled, outline, minWidth, outerSize, isSolid }) => ({
    pointerEvents: disabled ? 'none' : null,
    opacity: disabled ? 0.5 : null,
    borderRadius: outerSize * 0.5,
    minWidth: minWidth ? minWidth : outerSize,
    height: outerSize,
    extend: [
      button({
        fill: isSolid ? color : COLOR.TRANSPARENT,
        outline: outline ? null : 'none',
        border: {
          width: BUTTON.BORDER_WIDTH,
          color
        }
      }),
      layout({
        align: 'center'
      }),
      flex({
        shrink: 0
      }),
      transition({
        property: 'opacity',
        duration: TRANSITION.UI.duration,
        easing: TRANSITION.UI.easing
      })
    ],
    onHover: {
      opacity: 0.75
    },
    onActive: {
      opacity: 0.90
    }
  }),
  icon: ({ text, iconSize, innerSize }) => {
    const padding = offset(innerSize, iconSize)
    const paddingLeft = text ? padding + 8 : padding
    return edges({
      prefix: 'padding',
      edges: {
        top: padding,
        right: padding,
        bottom: padding,
        left: paddingLeft
      }
    })
  },
  text: ({ icon, innerSize }) => {
    const padding = innerSize * 0.5
    const paddingLeft = icon ? 2 : padding
    return {
      extend: [
        flex({
          grow: 1,
          shrink: 0
        }),
        edges({
          prefix: 'padding',
          edges: {
            right: padding,
            left: paddingLeft
          }
        })
      ]
    }
  }
})
